@@ -41,11 +41,9 @@
 #include <sonnet/spellcheckdecorator.h>
 #include <kcursor.h>
 #include <kstandardaction.h>
-#include <kicontheme.h>
 #include <kstandardshortcut.h>
 #include <klocalizedstring.h>
 #include <kmessagebox.h>
-#include <kwindowsystem.h>
 
 #include "kreplacedialog.h"
 #include "kfinddialog.h"
@@ -548,9 +546,6 @@ QMenu *KTextEdit::mousePopupMenu()
             popup->insertAction(separatorAction, clearAllAction);
         }
     }
-    KIconTheme::assignIconsToContextMenu(isReadOnly() ? KIconTheme::ReadOnlyText
-                                         : KIconTheme::TextEditor,
-                                         popup->actions());
 
     if (!isReadOnly()) {
         popup->addSeparator();
@@ -803,7 +798,7 @@ void KTextEdit::replace()
     }
 
     if (d->repDlg) {
-        KWindowSystem::activateWindow(d->repDlg->winId());
+        d->repDlg->activateWindow();
     } else {
         d->repDlg = new KReplaceDialog(this, 0,
                                        QStringList(), QStringList(), false);
@@ -857,12 +852,10 @@ void KTextEdit::slotReplaceNext()
         viewport()->setUpdatesEnabled(false);
     }
 
-    KFind::Result res = KFind::NoMatch;
-
     if (d->replace->needData()) {
         d->replace->setData(toPlainText(), d->repIndex);
     }
-    res = d->replace->replace();
+    KFind::Result res = d->replace->replace();
     if (!(d->replace->options() & KReplaceDialog::PromptOnReplace)) {
         textCursor().endEditBlock(); // #48541
         if (d->lastReplacedPosition >= 0) {
@@ -929,11 +922,10 @@ void KTextEdit::slotFindNext()
         return;
     }
 
-    KFind::Result res = KFind::NoMatch;
     if (d->find->needData()) {
         d->find->setData(toPlainText(), d->findIndex);
     }
-    res = d->find->find();
+    KFind::Result res = d->find->find();
 
     if (res == KFind::NoMatch) {
         d->find->displayFinalDialog();
@@ -966,7 +958,7 @@ void KTextEdit::slotFind()
     }
 
     if (d->findDlg) {
-        KWindowSystem::activateWindow(d->findDlg->winId());
+        d->findDlg->activateWindow();
     } else {
         d->findDlg = new KFindDialog(this);
         connect(d->findDlg, &KFindDialog::okClicked, this, &KTextEdit::slotDoFind);
@@ -981,7 +973,7 @@ void KTextEdit::slotReplace()
     }
 
     if (d->repDlg) {
-        KWindowSystem::activateWindow(d->repDlg->winId());
+        d->repDlg->activateWindow();
     } else {
         d->repDlg = new KReplaceDialog(this, 0,
                                        QStringList(), QStringList(), false);
